==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlMITaskPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import com.pulumi.core.Either
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Properties for task that migrates SQL Server databases to Azure SQL Database Managed Instance
 * @property clientData Key value pairs of client data to attach meta data information to task
 * @property commands Array of command properties.
 * @property errors Array of errors. This is ignored if submitted.
 * @property input Task input
 * @property output Task output. This is ignored if submitted.
 * @property state The state of the task. This is ignored if submitted.
 * @property taskType Task type.
 * Expected value is 'Migrate.SqlServer.AzureSqlDbMI'.
 */
public data class MigrateSqlServerSqlMITaskPropertiesResponse(
    public val clientData: Map<String, String>? = null,
    public val commands:
    List<Either<MigrateMISyncCompleteCommandPropertiesResponse, MigrateSyncCompleteCommandPropertiesResponse>>,
    public val errors: List<ODataErrorResponse>,
    public val input: MigrateSqlServerSqlMITaskInputResponse? = null,
    public val output: List<Any>,
    public val state: String,
    public val taskType: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlMITaskPropertiesResponse):
            MigrateSqlServerSqlMITaskPropertiesResponse = MigrateSqlServerSqlMITaskPropertiesResponse(
            clientData = javaType.clientData().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            commands = javaType.commands().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateMISyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateSyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }),
            errors = javaType.errors().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.ODataErrorResponse.Companion.toKotlin(args0)
                })
            }),
            input = javaType.input().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateSqlServerSqlMITaskInputResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            output = javaType.output().map({ args0 -> args0 }),
            state = javaType.state(),
            taskType = javaType.taskType(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/MigrateSqlServerSqlMITaskPropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import com.pulumi.core.Either
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Properties for task that migrates SQL Server databases to Azure SQL Database Managed Instance
 * @property clientData Key value pairs of client data to attach meta data information to task
 * @property commands Array of command properties.
 * @property errors Array of errors. This is ignored if submitted.
 * @property input Task input
 * @property output Task output. This is ignored if submitted.
 * @property state The state of the task. This is ignored if submitted.
 * @property taskType Task type.
 * Expected value is 'Migrate.SqlServer.AzureSqlDbMI'.
 */
public data class MigrateSqlServerSqlMITaskPropertiesResponse(
    public val clientData: Map<String, String>? = null,
    public val commands: List<Either<MigrateMISyncCompleteCommandPropertiesResponse, MigrateSyncCompleteCommandPropertiesResponse>>,
    public val errors: List<ODataErrorResponse>,
    public val input: MigrateSqlServerSqlMITaskInputResponse? = null,
    public val output: List<Any>,
    public val state: String,
    public val taskType: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.MigrateSqlServerSqlMITaskPropertiesResponse): MigrateSqlServerSqlMITaskPropertiesResponse = MigrateSqlServerSqlMITaskPropertiesResponse(
            clientData = javaType.clientData().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            commands = javaType.commands().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateMISyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateSyncCompleteCommandPropertiesResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }),
            errors = javaType.errors().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.ODataErrorResponse.Companion.toKotlin(args0)
                })
            }),
            input = javaType.input().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.datamigration.kotlin.outputs.MigrateSqlServerSqlMITaskInputResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            output = javaType.output().map({ args0 -> args0 }),
            state = javaType.state(),
            taskType = javaType.taskType(),
        )
    }
}
